====
pydl
====

Description
-----------

This package consists of Python_ replacements for functions that are part of
the `IDL®`_ built-in library or part of astronomical `IDL®`_ libraries.
The emphasis is on reproducing results of the astronomical library functions.
Only the bare minimum of `IDL®`_ built-in functions are implemented to support this.

There are four astronomical libraries targeted:

* idlutils_ : a general suite of tools heavily used by SDSS_.
* `Goddard utilities`_ : The `IDL®`_ Astronomy User's Libary, maintained by Wayne Landsman and distributed with idlutils_.
* idlspec2d_ : tools for working with SDSS_ and BOSS_ spectroscopic data.
* photoop_ : tools for working with SDSS_ imaging data.

This package affiliated with the astropy_ project and is registered with PyPI_.

History
-------

This package was initially developed on the SDSS-III_ `svn repository`_.  It was
moved to the new GitHub_ repository on 2013-03-06.  The present location of
the repository is http://github.com/weaverba137/pydl .

Legal
-----

* IDL is a registered trademark of `Exelis Visual Information Solutions`_.

.. _Python: http://python.org
.. _`IDL®`: http://www.exelisvis.com/language/en-us/productsservices/idl.aspx
.. _idlutils: http://www.sdss3.org/dr10/software/idlutils.php
.. _SDSS: http://www.sdss.org
.. _`Goddard utilities`: http://idlastro.gsfc.nasa.gov/
.. _idlspec2d: http://www.sdss3.org/svn/repo/idlspec2d/trunk/
.. _BOSS: http://www.sdss3.org/surveys/boss.php
.. _photoop: http://www.sdss3.org/svn/repo/photoop/trunk/
.. _astropy: http://www.astropy.org
.. _PyPI: https://pypi.python.org/pypi/pydl/
.. _SDSS-III: http://www.sdss3.org
.. _`svn repository`: http://www.sdss3.org/dr10/software/products.php
.. _GitHub: http://github.com
.. _`Exelis Visual Information Solutions`: http://www.exelisvis.com
